/* Schedwi
   Copyright (C) 2007-2010 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
 * send_process.h -- Management functions for the process which is responsible
 *                   for the send of the job results to the server
 */

#ifndef _SEND_PROCESS_H
#define _SEND_PROCESS_H

#include <schedwi.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int send_process_start OF((char open_log));
extern void send_process_stop OF(());
extern void send_process_wakeup OF(());
extern void send_process_term OF(());
extern void send_process_kill OF(());

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* send_process.h */

/*-----------------============== End Of File ==============-----------------*/
